.. include:: ../BADGES.rst

Command Line
============

Help::

    hspf_utils --help

about
~~~~~
.. program-output:: hspf_utils about --help
   :prompt:

detailed
~~~~~~~~
.. program-output:: hspf_utils detailed --help
   :prompt:

_detailed_cli
~~~~~~~~~~~~~
.. program-output:: hspf_utils _detailed_cli --help
   :prompt:

mapping
~~~~~~~
.. program-output:: hspf_utils mapping --help
   :prompt:

parameters
~~~~~~~~~~
.. program-output:: hspf_utils parameters --help
   :prompt:

summary
~~~~~~~
.. program-output:: hspf_utils summary --help
   :prompt:
